# Odin Ml

<!-- [![PyPi Version](https://img.shields.io/pypi/v/odin-ml)](https://pypi.org/project/odin-ml/) -->

<!-- [![Actions Status](https://github.com/blester125/odin-ml/workflows/Unit%20Test/badge.svg)](https://github.com/blester125/odin-ml/actions) -->

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
